# `python-code-data`

[![Test workflow](https://github.com/metadsl/python-code-data/actions/workflows/test.yml/badge.svg)](https://github.com/metadsl/python-code-data/actions/workflows/test.yml?query=branch%3Amain) [![Documentation Status](https://readthedocs.org/projects/python-code-data/badge/?version=latest)](https://python-code-data.readthedocs.io/en/latest/?badge=latest) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/metadsl/python-code-data/main)

`python-code-data` is a tool for introspecting Python code as data objects, by translating from Python's built in Code object.
